% File <Akinivec_for_Erlang_dists.m>
%
% Author: Falko Bause
% Date: June 2016  changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [Ak,inivec] = Akinivec_for_Erlang_dists(M,Erlang_length)

% M must be a matrix where each column contains the moments (0-th to K-th)
% of an Erlang distribution. We do NOT check whether M satisfies this
% constraint!

% Erlang_length denotes the number of states of an individual Erlang
% distribution. Note that we assume that all Erlang dists are of the same
% length

% BTW note that M together with an appropriate vector pi describes an
% Hyper-Erlang distribution

N = size(M,2);

Ak = {};    % Ak list of matrices
            % each matrix describes a single Erlang distribution specified by
            %  the tuple [rate  number_of_phases/states_of_erlang_distribution]

            % Remark: Erlang_length == 123456789   indicates a deterministic distribution

for i=1:N
    assert(M(2,i) > 0,'Akinivec_for_Erlang_dists: Moment M(2,i) is zero!');
    Ak{i} = [(Erlang_length/(1.0*M(2,i))) Erlang_length];
end


% Setting inivec is easy, since an Erlang dist starts in the first state:

inivec = {};
for i=1:N
    inivec{i} = [1.0 Erlang_length];
end


