% File <Akinivec_for_deterministic.m>
%
% Author: Falko Bause
% Date: June 2016  changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%

function [Ak,inivec] = Akinivec_for_deterministic_dists(M)

% M must be a matrix where each column contains the moments (0-th to K-th)
% of a deterministic distribution. We do NOT check whether M satisfies this
% constraint!

% The result is a one dimensional matrix Ak where the first entry
% is the rate value lambda and the second entry is the number
% 123456789 to indicate a deterministic distribution

% inivec is just the simple corresponding 2-dimensional vector = (1,123456789).

Ak = {};

assert(M(2,1) ~= 0,'Akinivec_for_deterministic_dists: Moment M(2,i) is zero!');
Ak{1} = [(1.0/M(2,1)) 123456789];

inivec = {};
inivec{1} = zeros(1,2);
inivec{1}(1,1) = 1.0;
inivec{1}(1,2) = 123456789;


