% File <delete_less_relevant_components.m>
%
% Author: Falko Bause
% Date: February 2019
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [M,pivec,Ak,inivec,N,C,component_deleted] = delete_less_relevant_components(M,pivec,Ak,inivec,N,distmoments,C,epsilon)
% delete those components (and entries in M, Q and pivec)
% for which the corresponding pivec*moments vector entries are less than the given epsilon values of the trace moments,
% since they contribute less to the overall distribution

fprintf('Function delete_less_relevant_entries started. epsilon=%E\n',epsilon);  printtime();
no_deleted_elements = 0;

i = 1;
component_deleted = 0;
ED = epsilon*distmoments;

for i=1:N
    PM = pivec(i)*M(:,i)';
    cmpvector = lt(PM,ED);
    cmpval = min(cmpvector(2:length(distmoments)));
    if (cmpval >= 1)    % comparison of vectors
        component_deleted = 1;
        no_deleted_elements = no_deleted_elements + 1;
        pivec(1,i) = 0;
        % delete distribution from lists
        Ak{i} = [];
        inivec{i} = [];
        M(:,i) = -9999;   % can't delete column here since of operation pivec(i)*M(:,i)' at the start of this for-loop
                          % so just mark it for later deletion
        C(:,i-(no_deleted_elements - 1)) = []; 
    end
end

no_deleted_M_columns = 0;
for i=1:N
    if (M(1,(i-no_deleted_M_columns)) <= -9999)
        M(:,(i-no_deleted_M_columns)) = [];  % delete column i
               % is a bit tricky see comment to the same operation in
               % file delete_pi_zero_entries_fast        
        no_deleted_M_columns = no_deleted_M_columns + 1;        
    end
end

N = N - no_deleted_elements;

% rearrange other lists and vectors:
pivec(pivec==0) = [];
Ak = Ak(~cellfun('isempty',Ak));
inivec = inivec(~cellfun('isempty',inivec));
fprintf('Function delete_less_relevant_entries ended. epsilon = %E, no_deleted_elements = %d \n',epsilon,no_deleted_elements);  printtime();
