% File <delete_pi_zero_entries_fast.m>
%
% Author: Falko Bause
% Date: February 2019
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [M,pivec,Ak,inivec,N,C,component_deleted] = delete_pi_zero_entries_fast(M,pivec,Ak,inivec,N,C,epsilon)
    % delete those components (and entries in M, C, d and pivec etc.)
    % for which the corresponding pivec entry is less than the given epsilon value,
    % since they are irrelevant
    
  fprintf('Function delete_pi_zero_entries_fast started. epsilon=%E\n',epsilon);  printtime();
  no_deleted_elements = 0;

  i = 1;
  component_deleted = 0;

  for i=1:N
    if (pivec(1,i) <  epsilon)
     component_deleted = 1;
     no_deleted_elements = no_deleted_elements + 1;
     pivec(1,i) = 0;
     % delete distribution from lists
     Ak{i} = [];
     inivec{i} = [];
     M(:,i-(no_deleted_elements - 1)) = [];   % Remark: Usual arrays are handled differently than cell arrays 
                                              %  Cell arrays here do not
                                              %  change dimension in for
                                              %  loop, matrix M does!
     C(:,i-(no_deleted_elements - 1)) = []; 
    end
  end
  
  N = N - no_deleted_elements;

  % rearrange lists and vectors:
  pivec(pivec==0) = [];
  Ak = Ak(~cellfun('isempty',Ak)); 
  inivec = inivec(~cellfun('isempty',inivec)); 
  fprintf('Function delete_pi_zero_entries_fast ended. epsilon = %E, no_deleted_elements = %d \n',epsilon,no_deleted_elements);  printtime();
