% File <determine_cdftvalues.m>
%
% Author: Falko Bause
% Date: June 2016  changed March 2018 (additional print line at the end)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%

function [ tvalues ] = determine_cdftvalues( trace, noelems )
% determine noelems number of tvalues which are later used as points for
% fitting of CDF

L = length(trace);

if (noelems > L)
   fprintf('Function determine_cdftvalues:  Warning noelems > L !!!  Setting noelems to L!\n');
   noelems = L;
end

sortedtrace = sort(trace);
tvalues = zeros(noelems,1);
% Generate all interim points and store them in tvalues
% Interim points are chosen such that the probability of trace value x in [tvalues(i-1),tvalues(i)]
% is approximately 1/noelems
for j=1:noelems
    % tvals are the interim points
    traceindex = round(j*L/noelems);
    tval = sortedtrace(traceindex);
    tvalues(j,1) = tval;
end

%ensure that all tvalues are distinct:
tvalues = unique(tvalues);  
fprintf('Function determine_cdftvalues:  Number of unique(!) CDF points used is %d, requested were %d CDF points\n',length(tvalues),noelems);
% dependent on trace charactersitics too many CDF points might be
% requested, which is changed by unique function. This might lead to
% inadequate numbers of vars and eqns for later lsqlin call.

% the resultant points of tvalues might violate the equal probilities of
% 1/noelems for the probability of trace value 
% x in [tvalues(i-1),tvalues(i)] 
