% File <epdf_and_cdfatvals_with_ksdensity.m>
%
% Author: Falko Bause
% Date: June 2016
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [epdfvec, ecdfvec, pdftvalues, xval] = epdf_and_cdfatvals_with_ksdensity(trace,xval)

% calculates the (approximate) empirical cdf (cumulative density function) at points xval
% using Matlab function ecdf for the given trace
% and calculates the empirical pdf of the trace at points using the
% standard kernel estimator of Matlab, ksdensity


[f,x] = ecdf(trace);
N = length(xval);
ecdfvec = zeros(1,N);

for i=1:N
    ecdfvec(i) = max(f(x<=xval(i)));
end

% % delete outliers!?
% origmean = mean(trace);
% qtr = quantile(trace,10000);
% maxtmp = qtr(10000);
% mintmp = qtr(1);
% Ltrold = length(trace);
% tracenew = trace(trace < maxtmp & trace > mintmp);
% Ltr = length(tracenew);
% newmean = mean(tracenew);
% if (abs((origmean-newmean)/origmean) < 0.05)
%     trace = tracenew;
%     fprintf('Deleting OUTLIERS!!!\n');
% end
% fprintf('Original trace length = %d, length after deleting outliers = %d  ===>  ratio is %E\n',Ltrold,Ltr,(Ltr/Ltrold));
%

mintr = min(trace);
maxtr = max(trace);
Ltr = length(trace);

% Determine number of bins for PDF histogram using Freedman/Diaconis rule:
rangetr = iqr(trace);  % Determine interquartile range of the trace
% https://en.wikipedia.org/wiki/Freedman%E2%80%93Diaconis_rule
% https://en.wikipedia.org/wiki/Histogram
binsize = 2*rangetr / (Ltr^(1/3));
no_pdfpoints = round((maxtr-mintr)/binsize);
if (no_pdfpoints > 1000)
    fprintf('Setting the number of points for the PDF values to 1000!!!!\n Recommended value from Freedman/Diaconis rule was %d which would lead to a large number of equations for NNLS problem definition!\n\n',no_pdfpoints);
    no_pdfpoints = 1000;
%     fprintf('Additionally deleting OUTLIERS!!!\n');
%     Ltrold = length(trace);
%     qtr = quantile(trace,10000);
%     maxtmp = qtr(10000);
%     mintmp = qtr(1);
%     tracenew = trace(trace < maxtmp & trace > mintmp);
%     Ltr = length(tracenew);
%     newmean = mean(tracenew);
%     trace = tracenew;
%     fprintf('Original trace length = %d, length after deleting outliers = %d  ===>  ratio is %E\n',Ltrold,Ltr,(Ltr/Ltrold));
%     mintr = min(trace);
%     maxtr = max(trace);
%     Ltr = length(trace);
end

pts = linspace(mintr,maxtr,no_pdfpoints);
[epdfvec,pdftvalues] = ksdensity(trace,pts,'Support','positive');
pdftvalues = pdftvalues';

% prtmat = [pdftvalues epdfvec'];
% fprintf('====== pdftvalues   epdfvec   Start ========= \n');
% disp(prtmat);
% fprintf('====== pdftvalues   epdfvec   End ========= \n');
