% File <erlang_dtm_cdf.m>
%
% Author: Falko Bause
% Date: June 2016    changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [cdfvec] = erlang_dtm_cdf(Ak,tvalues)

% Ak is assumed to contain an Erlang (or deterministic) distribution.
% tvalues are the values for which the CDF values of this Erlang/dtm distribution
% should be calculated. 
% The result is a vector cdfvec such that cdfvec(i) is the value of the CDF
% at value tvalues(i).

N = Ak(1,2);
T = length(tvalues);

    if (Ak(1,2) == 123456789)
        % deterministic dist:
        detval = abs(1.0/Ak(1,1));
        cdfvec = zeros(1,T);
        for i=1:T
            if (tvalues(i) > detval)
                cdfvec(i) = 1.0;
            end
        end
	return;
    end


% Ak should be an Erlang dist:
g2 = abs(1.0/Ak(1,1));
g1 = N;

% use the gamma dist for Erlang dist calculation:
cdfvec = gamcdf(tvalues,g1,g2);



    

