% File <erlang_dtm_pdf.m>
%
% Author: Falko Bause
% Date: June 2016    changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%

function [pdfvec] = erlang_dtm_pdf(Ak,tvalues)

% Ak is assumed to contain an Erlang distribution.
% tvalues are the values for which the PDF values of this Erlang/dtm distribution
% should be calculated. 
% The result is a vector pdfvec such that pdfvec(i) is the value of the PDF
% at value tvalues(i).

N = Ak(1,2);
T = length(tvalues);

    if (Ak(1,2) == 123456789)
        % deterministic dist:
        detval = abs(1.0/Ak(1,1));
        pdfvec = zeros(1,T);
        for i=1:T
            if (i>1)
              if (detval >= tvalues(i-1) && (detval < tvalues(i)))
                 pdfvec(i) = 1.0/(tvalues(i)-tvalues(i-1)); 
              end
            else
             if (detval < tvalues(i))
                 pdfvec(i) = 1.0/(tvalues(i)); 
             end                
            end
            return;
        end
    end

% Ak should be an Erlang dist:
g2 = abs(1.0/Ak(1,1));
g1 = N;

% use the gamma dist for Erlang dist calculation:
pdfvec = gampdf(tvalues,g1,g2);



    

