% File <generate_sorted_hypererlang_random_variates.m>
%
% Author: Falko Bause
% Date: August 2016   changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [ ] = generate_sorted_hypererlang_random_variates(pivec,inivec,Ak,no_of_random_variates,filename)

  % Generates approximately no_of_random_variates variates of the Hyper-Erlang distribution
  % specified by pivec and inivec,Ak and writes them to file filename.

  % Note: Whether (inivec,Ak) contains a list of Erlang distributions is not checked!
							  
  % Since we are only interested in the distribution the resultant trace is "sorted" !!!!!!!!
  % such that the first random variates are from the first Erlang distribution,
  % the next sequence of random variates is from the second Erlang distribution etc.
							  
fid = fopen(filename,'wt');

rng default; % Mersenne Twister should be the default

N = length(pivec);

for erlangdist=1:N
    % generate several (the amount is determined by vector pivec) random variates  
    vals = gamrnd( Ak{erlangdist}(1,2),(1.0/abs(Ak{erlangdist}(1,1))), round(pivec(erlangdist)*no_of_random_variates),1 );
    % write values to trace file
    if (~isempty(vals))
      fprintf(fid,'%e\n',vals);
    end
end

fclose(fid);
