#!/usr/bin/sh
# Parameters = GFit Parameters

# This skript can be seen as a black-box capsulating the execution of GFit. 
# First the Input Tracefile is converted, then GFit is executed, finally the 
# result is converted into the standart XML-Map format.

# ATTENTION: Skript must be executed directly from its directory

# Example:
#  ./gfit.sh -a 20  1 15
#    Call gfit using trace file local.trace with parameter setting
#     -a <N> <m_min> <m_max>  = fit all settings of a hyper-Erlang distribution and return the best fitted distribution.
#                               <N> is the overall number of (internal) states used by the hyper-Erlang distribution,
#                               <m_min> is the minimal number of Erlang branches to be used and
#                               <m_max> is the maximal number of Erlang branches (1 <= m_min <= m_max <= N).
# Here: N=20 m_min=1 m_max=15

# Call ./gfit  getting help for further parameter settings.


# G-Fit needs the number of elements of the trace at the beginning of the trace file for allocating storage
# so we use a copy of the trace file for the G-Fit call (surely not a very efficient solution :-(
LINECOUNT=`wc -l local.trace | awk '{print $1;}'`
\cp local.trace local.tracegfit
\sed -i '1i '${LINECOUNT} local.tracegfit   # insert at file's head position

# Execute G-Fit
./gfit "local.tracegfit" $@

# Create XML Output
`./GFitToXMLMap.tcl "gfit.result" "gfit.res"`

\rm -f gfit.result local.tracegfit

