% File <kvalues.m>
%
% Author: Falko Bause
% Date: October 2016
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [ values ] = kvalues(n,betaval)

% generates and returns a sequence of integer numbers in ]0,infty[ using a Farey sequence from [0,1] of order n
% which determine a point on the (first quadrant) of the unit circle and afterwards using a stereographic projection
% ( projval = x/(1-y)  with x^2+y^2=1)
% gives the resultant number (after being exponentially transformed and rounded). Transformation is
% done to get a wider spread. betaval is a scaling factor.
% Note that the point (0,1) which is mapped to value infinity is excluded.

values = [];

farvalues = farey_points(n);
len = length(farvalues);

for i=1:len
    if farvalues(i) > 0
        projval = (farvalues(i)/(1-(sin(acos(farvalues(i)))))); % = x/(1-y)
    else
        projval = 0;
    end
    intval = max(1,round(exp(betaval*projval))); % Transformation of projval!
    values = horzcat(values,intval);
end
values = values(~isinf(values)); % delete possible infinite values resultant from exponential transformation
values = unique(sort(values));

% values = values(values <= 10000000); % for technical reasons (maximum matrix size) larger values are deleted!!!!


% check consecutive element occurrence  (only for test; can be deleted!)
% len = length(values);
% for i=1:len
%     if (values(i) > i)
%         fprintf('kvalues: Consecutive numbers up to %d are in values list!\n',(i-1));
%         return;
%     end
% end


