% File <lauf.m>
%
% Author: Falko Bause
% Date: January 2018
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [res] = lauf()

% Makes a series of fixed experiments using function fittracedist.

% ID for experiment series. All results of these experiments are moved to a
% directory with a name concatenated from 'RES_...' and variable
% IDEXPERIMENTS

res = 0;

jvm = 0;  % == 0  Matlab has been invoked with option -nojvm; otherwise set jvm to 1 (then also creating additional plots)
threshold_pre_analysis_of_trace = 0.0;  % is a parameter of function fittracedist
skip_norm2_error = 1e-04; % once this relative error has been obtained
% skip further experiment runs for the specific trace;
% is just to avoid unnecessary runs (e.g. only a
% few variables (nvars1,nvars2) are needed for
% fitting an exponential distribution and it is
% not necessary to do further experiments with increased values)



% For ProFiDo:
plotstart = 0.1; % start value of x axis for pdf/cdf plots
plotend   = 10;  % end value of x axis for pdf/cdf plots
traceend  = 10;  % maximum value of trace
plotwidth = 0.1; % width of a bin for pdf/cdf plots
numbins = 100;   % is changed later for each trace
% all these values are trace specific and are used as input to ProFiDo's plot.exe program
% in order to make consistent comparisons based on the same PDF representation
% the current settings are just default values to be changed later
% Next values are for all traces:
numsamples = 1000; % number of points at which theoretical(!) PDF/CDF is evaluated
lw_value = 1;  % value for plot parameter linewidth
% End of parameter list for ProFiDo



IDEXPERIMENTS = '040919';
resdir = ['RES_2019_for_paper_' IDEXPERIMENTS];

commandstr = ['mkdir -p ' resdir ];
[status,result] =  system(commandstr);


cdfpointvalues = [500,1000,1600];


traceidvalues = [1:58];
% traceidvalues = [1,3,6,12,22,24,25,51,52,54,57];


do_gfitmomfit_runs = 1;  % if >= 1 do runs with G-Fit and Momfit for comparisons
additional_gfit_parameter_list = {'-lta 100'}; % G-Fit with trace aggregation (for large traces)

list_nvars1and2 = {[10,10],[20,20],[30,30],[40,40]}; % list of nvars1, nvars2 pairs for fittracedist function call

K = 10;  % max. moments   NOTE: for values <> 10  call parameters for Momfit/G-Fit have to be corrected manually!!
  
plotK = K;  % number of moments to plot with ProFiDo's plot program, usually set plotK = K
quant_no = 10; % number of quantiles used for building mixture components
novariates = 100000000; % number of variates which should (at least) be generated from the fitted distribution

statepenalty_factors = [0,10];  % (integer!) penalty factor for the number of states in an Erlang branch; will be part of NNLS problem definition

%  END OF USER INPUT (rest of source code should not be changed)


number_of_experiments = 0;
skip_next_runs_for_this_trace = 0; % might be done if larger values for nvars1, nvars2 are not necessary to examine;
% currently we skip further for loop values if the norm2_error is less than skip_norm2_error

for toggle = 1:2  % just to determine the number of experiments in a first go
    for traceiditer = 1:length(traceidvalues)
        traceid = traceidvalues(traceiditer);
        skip_next_runs_for_this_trace = 0;
        if (traceid == 1)
            tracestr = 'TRACES/lbl3.trace';
            numbins = 410;         % for comparisons use number of points/bins of Freedman-Diaconis approach
            % plotwidth is the bin size of the Freedman-Diaconis approach for the trace where outliers have been deleted
            %     might be changed if the number of bins is changed, see file epdf_and_cdfatvals.m
            % plotstart is the minimum trace value
            % traceend is the maximum trace value
            % plotend is the last value for the plot (might be significantly less than traceend
            %    if one is not interested in the presentation of the right part of the PDF)
            plotwidth = 0.0166; plotstart = 0.0291; traceend = 6.8321; plotend =  4;
            plotstart = 0.05;
        end
        if (traceid == 2)
            tracestr = 'TRACES/tudotrace_sorted_shortend.trace';
            %fprintf('\n\nATTENTION: USING sorted and shortened trace (last 200 elements of sorted trace were deleted)!!!\n');
            numbins = 7572;
            plotwidth = 0.0071; plotstart = 0.0034; traceend = 14.1945; plotend =  4;
        end
        if (traceid == 3)
            tracestr = 'TRACES/pAug89_dat.trace';
            numbins = 527;
            plotwidth = 0.0166; plotstart = 0.0242; traceend = 8.7577; plotend =  2; % 5;
        end
        if (traceid == 4)
            tracestr = 'TRACES/wideA_200004041359.trace';
            numbins = 353;
            plotwidth = 0.0172; plotstart = 0.0396; traceend = 6.1159; plotend =  5;
        end
        if (traceid == 5)
            tracestr = 'TRACES/wideD_200704131800.trace';
            numbins = 357;
            plotwidth = 0.0228; plotstart = 2.7531e-04; traceend = 8.1439; plotend =  3;
            plotstart = 0.1;
        end
        if (traceid == 6)
            tracestr = 'TRACES/hypererlang.trace';
            numbins = 411;
            plotwidth = 0.0050; plotstart = 0.0263; traceend = 2.0910; plotend =  2;
            % plotstart = 0.1;
        end
        if (traceid == 7)
            tracestr = 'TRACES/expo.trace';
            numbins = 459;
            plotwidth = 0.0063; plotstart = 0.0062; traceend = 2.8837; plotend =  2;
            % plotstart = 0.1;
        end
        if (traceid == 8)
            tracestr = 'TRACES/normal_only_positive.trace';
            numbins = 370;
            plotwidth = 0.0368; plotstart = 1.3844; traceend = 14.9960; plotend =  15;
        end
        if (traceid == 9)
            tracestr = 'TRACES/normal5_hypererlang.trace';
            numbins = 275;
            plotwidth = 0.0330; plotstart = 0.0441; traceend = 9.1189; plotend =  9;
            % plotstart = 0.1;
        end
        if (traceid == 10)
            tracestr = 'TRACES/expo3_normal8.trace';
            numbins = 466;
            plotwidth = 0.0285; plotstart = 0.9173; traceend = 14.1809; plotend =  14;
        end
        if (traceid == 11)
            tracestr = 'TRACES/trimodal.trace';
            numbins = 403;
            plotwidth = 0.0327; plotstart = 0.0734; traceend = 13.2402; plotend =  13;
        end
        if (traceid == 12)
            tracestr = 'TRACES/uniform_between_1_11.trace';
            numbins = 99;
            plotwidth = 0.0490; plotstart = 1.0991; traceend = 10.9013; plotend =  11;
        end
        if (traceid == 13)
            tracestr = 'TRACES/beta3.trace';
            numbins = 80;
            plotwidth = 0.0050; plotstart = 0.0010; traceend = 0.9988; plotend =  1;
            % plotstart = 0.05; plotend = 0.95;
        end
        if (traceid == 14)
            tracestr = 'TRACES/betaA.trace';
            numbins = 202;
            plotwidth = 7.0336e-04; plotstart = 3.2489e-04; traceend = 0.1424; plotend = 0.15;
        end
        if (traceid == 15)
            tracestr = 'TRACES/betaB.trace';
            numbins = 202;
            plotwidth = 8.3363e-04; plotstart = 0.8312; traceend = 0.9996; plotend =  1;
        end
        if (traceid == 16)
            tracestr = 'TRACES/betaC.trace';
            numbins = 165;
            plotwidth = 0.0025; plotstart = 0.2540; traceend = 0.7462; plotend =  0.7;
        end
        if (traceid == 17)
            tracestr = 'TRACES/epa_dat.trace';
            numbins = 444;
            plotwidth = 0.0222; plotstart = 0.0101; traceend = 9.8743; plotend =  2;
        end
        if (traceid == 18)
            tracestr = 'TRACES/arrivals_AcadBldg18.trace';
            numbins = 1118;
            plotwidth = 1.6091; plotstart = 2; traceend = 1801; plotend =  200;
        end
        if (traceid == 19)
            tracestr = 'TRACES/microsoft99_avail.trace';
            numbins = 455;
            plotwidth = 6.3059e+03; plotstart = 7200; traceend = 2876400; plotend =  500000;
        end
        if (traceid == 20)
            tracestr = 'TRACES/microsoft99_uavail.trace';
            numbins = 460;
            plotwidth = 1.6513e+03; plotstart = 7200; traceend = 766800; plotend =  500000;
        end
        if (traceid == 21)
            tracestr = 'TRACES/synth_trace/lognormal10000_1.0_1.5.trace';
            numbins = 90;
            plotwidth = 0.0363; plotstart = 0.0471; traceend = 7.3080; plotend =  3;
            % plotstart = 0.2;
        end
        if (traceid == 22)
            tracestr = 'TRACES/synth_trace/matrix_exp10000.trace';
            numbins = 46;
            plotwidth = 0.0225; plotstart = 0.1190; traceend = 4.6143; plotend =  4;
        end
        if (traceid == 23)
            tracestr = 'TRACES/synth_trace/paretoII10000_1.5_2.0.trace';
            numbins = 173;
            plotwidth = 0.1811; plotstart = 0.3534; traceend = 36.5722; plotend =  10;
        end
        if (traceid == 24)
            tracestr = 'TRACES/synth_trace/paretoII_107_1.5_2.0.trace';
            numbins = 1645;
            plotwidth = 0.0211; plotstart = 0.3520; traceend = 35.0636; plotend =  10;
            % plotstart = 0.2;
        end
        if (traceid == 25)
            tracestr = 'TRACES/synth_trace/shifted_exp10000.trace';
            numbins = 45;
            plotwidth = 0.0264; plotstart = 0.0204; traceend = 5.2967; plotend =  5;
        end
        if (traceid == 26)
            tracestr = 'TRACES/synth_trace/triangular10000_0.3_0.8_1.7.trace';
            numbins = 31;
            plotwidth = 0.0060; plotstart = 0.3822; traceend = 1.5787; plotend =  1.6;
        end
        if (traceid == 27)
            tracestr = 'TRACES/synth_trace/uniform10000_0.0_1.0.trace';
            numbins = 21;
            plotwidth = 0.0049; plotstart = 0.0097; traceend = 0.9883; plotend =  1;
            % plotstart = 0.05;
        end
        if (traceid == 28)
            tracestr = 'TRACES/synth_trace/uniform10000_0.5_1.5.trace';
            numbins = 21;
            plotwidth = 0.0049; plotstart = 0.5097; traceend = 1.4883; plotend =  1.5;
            % plotstart = 0.49;
        end
        if (traceid == 29)
            tracestr = 'TRACES/synth_trace/weibull10000_1.0_0.5.trace';
            numbins = 131;
            plotwidth = 0.1055; plotstart = 8.7501e-05; traceend = 21.1009; plotend =  2;
            % plotstart = 0.2;
        end
        if (traceid == 30)
            tracestr = 'TRACES/synth_trace/weibull10000_1.0_5.0.trace';
            numbins = 35;
            plotwidth = 0.0047; plotstart = 0.4112; traceend = 1.3593; plotend =  1.3;
        end
        if (traceid == 31)
            tracestr = 'TRACES/lbl3_trunc.trace';
            numbins = 98;
            plotwidth = 0.0453; plotstart = 0.0293; traceend = 9.0919; plotend = 3;
            % plotstart = 0.05;
        end
        if (traceid == 32)
            tracestr = 'TRACES/tudo_interarrival_trunc.trace';
            numbins = 260;
            plotwidth = 0.1820; plotstart = 0.0034; traceend = 47.3149; plotend =  2;
        end
        if (traceid == 33)
            tracestr = 'TRACES/pAug89_dat_trunc.trace';
            numbins = 148;
            plotwidth = 0.0349; plotstart = 0.0267; traceend = 7.0115; plotend =  2; % 5;
        end
        if (traceid == 34)
            tracestr = 'TRACES/wideA_200004041359_trunc.trace';
            numbins = 65;
            plotwidth = 0.0323; plotstart = 0.0396; traceend = 6.5000; plotend =  3; % 5;
            % plotstart = 0.1;
        end
        if (traceid == 35)
            tracestr = 'TRACES/wideD_200704131800_trunc.trace';
            numbins = 64;
            plotwidth = 0.0393; plotstart = 2.2525e-04; traceend = 7.8670; plotend =  2;
            % plotstart = 0.1;
        end
        if (traceid == 36)
            tracestr = 'TRACES/hypererlang_trunc.trace';
            numbins = 43;
            plotwidth = 0.0107; plotstart = 0.0261; traceend = 2.1708; plotend =  2;
            % plotstart = 0.1;
        end
        if (traceid == 37)
            tracestr = 'TRACES/expo_trunc.trace';
            numbins = 60;
            plotwidth = 0.0150; plotstart = 0.0054; traceend = 2.9989; plotend =  3;
            % plotstart = 0.1;
        end
        if (traceid == 38)
            tracestr = 'TRACES/normal_only_positive_trunc.trace';
            numbins = 47;
            plotwidth = 0.0678; plotstart = 1.3958; traceend = 14.9559; plotend =  15;
        end
        if (traceid == 39)
            tracestr = 'TRACES/normal5_hypererlang_trunc.trace';
            numbins = 27;
            plotwidth = 0.0454; plotstart = 0.0470; traceend = 9.1193; plotend =  9;
            % plotstart = 0.1;
        end
        if (traceid == 40)
            tracestr = 'TRACES/expo3_normal8_trunc.trace';
            numbins = 47;
            plotwidth = 0.0662; plotstart = 0.9440; traceend = 14.1789; plotend =  14;
        end
        if (traceid == 41)
            tracestr = 'TRACES/trimodal_trunc.trace';
            numbins = 45;
            plotwidth = 0.0643; plotstart = 0.0857; traceend = 12.9444; plotend =  12;
        end
        if (traceid == 42)
            tracestr = 'TRACES/uniform_between_1_11_trunc.trace';
            numbins = 27;
            plotwidth = 0.0490; plotstart = 1.0939; traceend = 10.8919; plotend =  11;
        end
        if (traceid == 43)
            tracestr = 'TRACES/beta3_trunc.trace';
            numbins = 17;
            plotwidth = 0.0050; plotstart = 0.0010; traceend = 0.9988; plotend =  1;
            % plotstart = 0.05; plotend = 0.95;
        end
        if (traceid == 44)
            tracestr = 'TRACES/betaA_trunc.trace';
            numbins = 43;
            plotwidth = 6.7950e-04; plotstart = 3.5040e-04; traceend = 0.1363; plotend =  0.15;
        end
        if (traceid == 45)
            tracestr = 'TRACES/betaB_trunc.trace';
            numbins = 43;
            plotwidth = 8.5130e-04; plotstart = 0.8293; traceend = 0.9996; plotend =  1;
        end
        if (traceid == 46)
            tracestr = 'TRACES/betaC_trunc.trace';
            numbins = 36;
            plotwidth = 0.0024; plotstart = 0.2600; traceend = 0.7446; plotend =  0.7;
        end
        if (traceid == 47)
            tracestr = 'TRACES/arrivals_AcadBldg18_trunc.trace';
            numbins = 628;
            plotwidth = 32.8631; plotstart = 3; traceend = 20641; plotend =  20000;
        end
        if (traceid == 48)
            tracestr = 'TRACES/microsoft99_avail_trunc.trace';
            numbins = 165;
            plotwidth = 15030; plotstart = 7200; traceend = 3013200; plotend =  500000;
        end
        if (traceid == 49)
            tracestr = 'TRACES/microsoft99_uavail_trunc.trace';
            numbins = 156;
            plotwidth = 3456; plotstart = 7200; traceend = 698400; plotend =  500000;
        end
        if (traceid == 50)
            tracestr = 'TRACES/synth_trace/paretoII_107_1.5_2.0_trunc.trace';
            numbins = 204;
            plotwidth = 0.1664; plotstart = 0.3540; traceend = 34.2976; plotend =  10;
        end
        if (traceid == 51)
            tracestr = 'TRACES/triangular1_5_6.trace';
            numbins = 289;
            plotwidth = 0.015; plotstart = 1.0; traceend = 6.0; plotend =  7;
        end
        if (traceid == 52)
            tracestr = 'TRACES/uniformlong.trace';
            numbins = 214;
            plotwidth = 0.0137; plotstart = 1.0; traceend = 5.0; plotend =  6;
        end
        if (traceid == 53)
            tracestr = 'TRACES/johnsonSB.trace';
            numbins = 123;
            plotwidth = 0.0296; plotstart = 0.093327; traceend = 6.01876; plotend =  7;
        end
        if (traceid == 54)
            tracestr = 'TRACES/johnsonSB2.trace';
            numbins = 185;
            plotwidth = 0.1630; plotstart = 0.09116; traceend = 42.2311; plotend =  44;
        end
        if (traceid == 55)
            tracestr = 'TRACES/generalized_Pareto_1_10_200.trace';
            numbins = 18152;
            plotwidth = 0.00275; plotstart = 200; % traceend = 9820; 
            plotend =  250; traceend = plotend;
        end
        if (traceid == 56)
            tracestr = 'TRACES/generalized_Pareto_-5_10_200.trace';
            numbins = 183;
            plotwidth = 0.01366; plotstart = 200; % traceend = 202; 
            plotend =  202.5; traceend = plotend;
        end
        if (traceid == 57)
            tracestr = 'TRACES/beta3a.trace';
            numbins = 281;
            plotwidth = 0.0035; plotstart = 0.0010; plotend =  1; traceend = plotend;
        end
        if (traceid == 58)
            tracestr = 'TRACES/cauchy.trace';
            numbins = 15117;
            plotwidth = 0.04; plotstart = 0; % traceend = 3116118; 
            plotend = 15; traceend = plotend;
        end

        [~,trnametmp,~] = fileparts(tracestr);
        tracename = strrep(trnametmp,'_','-');
        
        numbins = max(min(numbins,2000),200);              % should correspond to the "reasonable size" for no_pdfpoints in file epdf_and_cdfatvals.m
        plotwidth = round((traceend - plotstart)/numbins); % width calculated as in epdf_and_cdfatvals.m, just to have the same representation of the PDF
        % for the plot of ProFiDo and for shotgun's plot
        numbins = round((plotend-plotstart)/(traceend-plotstart)*numbins); % adjust numbins if plotend and traceend differ
        
        if (do_gfitmomfit_runs >= 1)
            gfitparamlistlength = length(additional_gfit_parameter_list);
        else
            gfitparamlistlength = 1; % No G-Fit Momfit call should be done.
        end
        
        for gfitrunno = 1:gfitparamlistlength
            if (do_gfitmomfit_runs >= 1)
                gfitparam = additional_gfit_parameter_list{gfitrunno};
            else
                gfitparam = ' ';
            end
            
            if (toggle > 1)
                if (do_gfitmomfit_runs >= 1)
                    fprintf('Starting runs of G-Fit and Momfit for traceid = %d! \n',traceid);
                    fprintf('Additional parameters of G-Fit call for possible comparisons:  %s  \n G-Fit run number is %d\n\n',gfitparam,gfitrunno);
                    
                    commandstr = ['\rm -f gfit.res momfit.res ']; % Delete possible old results
                    [status,result] =  system(commandstr);
                    
                    commandstr = ['cp -f ' tracestr ' gfitmomfit/local.trace; cd gfitmomfit; time ./momfit.sh 10 5 1000000 1.0e-08 10000 13; time ./gfit.sh -a 20 1 20 ' gfitparam ' ; mv -f momfit.res gfit.res ..; \rm -f local.trace; cd ..'];
                    [status,result] =  system(commandstr)
                    
                    fprintf('End of runs of G-Fit and Momfit for traceid = %d! \n',traceid);
                end
                
            end
            for pdfcdffit_only = 0:1:0    % two sets of runs are performed: one for pdfcdffit_only = 0 which fits PDF/CDF/Moments simultaneously and
                % one for pdfcdffit_only = 1 which fits only PDF/CDF  and giving usually a bad fit for the moments.
                % this all is only for comparisons for very "difficult" traces (e.g. 2,3,24 from list above)
                for listnvarscounter = 1:length(list_nvars1and2)
                    nvars1 = list_nvars1and2{listnvarscounter}(1);
                    nvars2 = list_nvars1and2{listnvarscounter}(2);
                    no_vars = nvars1*nvars2;
                    for stp_factor_counter = 1:length(statepenalty_factors)
                        stp_factor = statepenalty_factors(stp_factor_counter);
                        for cdfpointiter = 1:length(cdfpointvalues)
                            cdfpoints = cdfpointvalues(cdfpointiter);
                            % if ((no_vars <= cdfpoints))  % ensures that lsqlin problem definitions are adequate (more equations than variables).
                            if ((no_vars <= cdfpoints) && (no_vars >= (cdfpoints - 400)))  % ensures that lsqlin problem definitions are adequate (more equations than variables) and additionally that the number of equations is not unneccessarily high, (second condition can be removed).
                                if (toggle < 2)
                                    fprintf('traceid = %d, no_vars = %d, nvars1 = %d, nvars2 = %d, cdfpoints = %d, gfitrunno = %d, pdfcdffit_only= %d, stp_factor = %d\n',traceid,no_vars,nvars1,nvars2,cdfpoints,gfitrunno,pdfcdffit_only,stp_factor);
                                    number_of_experiments = number_of_experiments + 1;
                                end
                                if ((toggle > 1) && (skip_next_runs_for_this_trace < 1))
                                    diary on
                                    fprintf('Starting shotgun run for traceid = %d! \n',traceid);
                                    fprintf('Call of fittracedist( %s, %d, %d, %d, %d, %d, %E, %E, %d, %d, %d, %d)\n',tracestr,nvars1,nvars2,cdfpoints,K,quant_no,threshold_pre_analysis_of_trace,1.0e-05,novariates,pdfcdffit_only,jvm,stp_factor);
                                    [pivec,M,Ak,inivec,Nlag1states,deterministic_free,norm2_error] = fittracedist(tracestr,nvars1,nvars2,cdfpoints,K,quant_no,threshold_pre_analysis_of_trace,1.0e-05,novariates,pdfcdffit_only,jvm,stp_factor);
                                    
                                    if (norm2_error < skip_norm2_error)
                                        skip_next_runs_for_this_trace = 1;
                                    end
                                    % if ((Nlag1states < 0) && (Nlag1states > 0) && (deterministic_free > 0))  % don't use ProFiDo's plot programm
                                    if ((Nlag1states < 200) && (Nlag1states > 0) && (deterministic_free > 0))
                                        fprintf('Starting additional plots:\n');
                                        resstr = ['plotpdf' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only) '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        resstrdata = ['plotpdf' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.data'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdf -dist shotgun.profido " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdf.pdf ' resstr '; mv -f ' resstr ' ' resdir '; mv -f ergplotpdf_Trace_1.dat ' resstrdata '; mv -f ' resstrdata ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        resstr = ['plotcdf' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdf -dist shotgun.profido " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdf.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        resstr = ['plotccdf' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=ccdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotccdf -dist shotgun.profido " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotccdf.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        resstr = ['plotmom' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=1 -end=' int2str(plotK) ' -plot=mom -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotmom -trace ' tracestr ' -dist shotgun.profido " shotgun "; mv -f ergplotmom.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        fprintf('Additional Plot generations end.\n');
                                    end
                                    if ((novariates > 0))
                                        fprintf('Starting additional plots using trace generated from shotgun fit! \n');
                                        
                                        resstr = ['plotpdfusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdfcmp -trace shotgun.trace " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
  
                                        resstr = ['plotpdfloglogusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -logscale=true -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdfloglogcmp -trace shotgun.trace " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdfloglogcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                     
                                        resstr = ['plotcdfusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdfcmp -trace shotgun.trace " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotcdfloglogusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -logscale=true -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdfloglogcmp -trace shotgun.trace " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdfloglogcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotccdfusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=ccdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotccdfcmp -trace shotgun.trace " shotgun " -trace ' tracestr ' " " ' tracename '; mv -f ergplotccdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotmomusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=1 -end=' int2str(plotK) ' -plot=mom -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotmomcmp -trace ' tracestr ' -trace shotgun.trace " shotgun "; mv -f ergplotmomcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
%                                        resstr = ['plotppusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
%                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=0 -end=1.0 -plot=pp -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotppcmp -trace ' tracestr ' -trace shotgun.trace " shotgun "; mv -f ergplotppcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
%                                        [status,result] =  system(commandstr);
                                        
%                                        resstr = ['plotqqusingtraces' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
%                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=0 -end=' int2str(quant_no) ' -plot=qq -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotqqcmp -trace ' tracestr ' -trace shotgun.trace " shotgun "; mv -f ergplotqqcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
%                                        [status,result] =  system(commandstr);
                                        
                                        
                                        if (do_gfitmomfit_runs < 1) % trace is not needed for later comparisons with G-Fit, Momfit since they were not called
                                            resstr = ['shotgun' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.trace'];
                                            commandstr = ['mv -f shotgun.trace ' resstr '; mv -f ' resstr ' ' resdir];
                                            
                                            % *********************** Just to save disk space:  (otherwise delete/comment the next line)
                                            commandstr = ['\rm -f shotgun.trace'];
                                            
                                            [status,result] =  system(commandstr);
                                        end
                                        fprintf('Additional Plot generations using shotgun trace end.\n');
                                    end
                                    
                                    if ((Nlag1states > 0) && (Nlag1states < 200) && (do_gfitmomfit_runs >= 1))
                                        fprintf('Starting comparisons with G-Fit and Momfit using Hyper-Erlang description of shotgun fit! \n');
                                        
                                        resstr = ['plotpdforigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdfcmp -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotpdfloglogorigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -logscale=true -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdfloglogcmp -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdfloglogcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotcdforigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdfcmp -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotcdfloglogorigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -logscale=true -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdfloglogcmp -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdfloglogcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotccdforigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=ccdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotccdfcmp -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotccdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotmomorigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=1 -end=' int2str(plotK) ' -plot=mom -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotmomcmp -trace ' tracestr ' -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit "; mv -f ergplotmomcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                                                               
%                                        resstr = ['plotpporigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
%                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=0 -end=1.0 -plot=pp -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotppcmp -trace ' tracestr ' -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit "; mv -f ergplotppcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
%                                        [status,result] =  system(commandstr);
                                        
%                                        resstr = ['plotqqorigcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
%                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=0 -end=' int2str(quant_no) ' -plot=qq -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotqqcmp -trace ' tracestr ' -dist shotgun.profido " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit "; mv -f ergplotqqcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
%                                        [status,result] =  system(commandstr);


                                        fprintf('Plot generation of comparisons with MAP/PH description end.\n');
                                    end
                                    
                                    
                                    if ((novariates > 0) && (do_gfitmomfit_runs >= 1))
                                        fprintf('Starting comparisons with G-Fit and Momfit using trace generated from shotgun fit! \n');
                                        
                                        resstr = ['plotpdfcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdfcmp -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotpdfloglogcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=pdf -logscale=true -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotpdfloglogcmp -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotpdfloglogcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotcdfcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdfcmp -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotcdfloglogcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=cdf -logscale=true -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotcdfloglogcmp -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotcdfloglogcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotccdfcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=' num2str(plotstart) ' -end=' num2str(plotend) ' -numbins=' int2str(numbins) ' -numsamples=' int2str(numsamples) ' -plot=ccdf -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotccdfcmp -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit " -trace ' tracestr ' " " ' tracename '; mv -f ergplotccdfcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['plotmomcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=1 -end=' int2str(plotK) ' -plot=mom -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotmomcmp -trace ' tracestr ' -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit "; mv -f ergplotmomcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
%                                        resstr = ['plotppcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
%                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=0 -end=1.0 -plot=pp -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotppcmp -trace ' tracestr ' -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit "; mv -f ergplotppcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
%                                        [status,result] =  system(commandstr);
                                        
%                                        resstr = ['plotqqcmp' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
%                                        commandstr = ['timeout 3600 time ./plot.exe -modelFormat=xml -traceFormat=1 -format=pdf -start=0 -end=' int2str(quant_no) ' -plot=qq -linewidth=' int2str(lw_value) ' -template=linetype_defs_for_plot.def -output=ergplotqqcmp -trace ' tracestr ' -trace shotgun.trace " shotgun " -cph momfit.res " momfit " -cph gfit.res " gfit "; mv -f ergplotqqcmp.pdf ' resstr '; mv -f ' resstr ' ' resdir];
%                                        [status,result] =  system(commandstr);
                                     
                                        resstr = ['shotgun' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.trace'];
                                        commandstr = ['mv -f shotgun.trace ' resstr '; mv -f ' resstr ' ' resdir];
                                        
                                        % *********************** Just to save disk space:  (otherwise delete/comment the next line)
                                        commandstr = ['\rm -f shotgun.trace'];
                                        
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['momfit' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.result'];
                                        commandstr = ['cp -f momfit.res ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        resstr = ['gfit' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.result'];
                                        commandstr = ['cp -f gfit.res ' resstr '; mv -f ' resstr ' ' resdir];
                                        [status,result] =  system(commandstr);
                                        
                                        fprintf('End of comparisons with G-Fit and Momfit! \n');
                                    end
                                    
                                    
                                    diary off
                                    
                                    resstr = ['mat' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.profido'];
                                    commandstr = ['mv -f shotgun.profido ' resstr '; mv -f ' resstr ' ' resdir];
                                    [status,result] =  system(commandstr);
                                    
                                    resstr2 = ['diary' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only) '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) ];
                                    commandstr2 = ['mv -f diary ' resstr2 '; mv -f ' resstr2 ' ' resdir];
                                    [status,result] =  system(commandstr2);
                                    
                                    resstr2a = ['shotgunTRACEPDF' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr2a = ['mv -f shotgunTRACEPDF.pdf ' resstr2a '; mv -f ' resstr2a ' ' resdir];
                                    [status,result] =  system(commandstr2a);
                                    
                                    resstr3 = ['shotgunPDF' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr3 = ['mv -f shotgunPDF.pdf ' resstr3 '; mv -f ' resstr3 ' ' resdir];
                                    [status,result] =  system(commandstr3);
                                    
                                    resstr3a = ['shotgunPDFlogx' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr3a = ['mv -f shotgunPDFlogx.pdf ' resstr3a '; mv -f ' resstr3a ' ' resdir];
                                    [status,result] =  system(commandstr3a);
                                    resstr3b = ['shotgunPDFlogy' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr3b = ['mv -f shotgunPDFlogy.pdf ' resstr3b '; mv -f ' resstr3b ' ' resdir];
                                    [status,result] =  system(commandstr3b);
                                    resstr3c = ['shotgunPDFloglog' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr3c = ['mv -f shotgunPDFloglog.pdf ' resstr3c '; mv -f ' resstr3c ' ' resdir];
                                    [status,result] =  system(commandstr3c);
                                    
                                    resstr4 = ['shotgunCDF' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr4 = ['mv -f shotgunCDF.pdf ' resstr4 '; mv -f ' resstr4 ' ' resdir];
                                    [status,result] =  system(commandstr4);
                                    
                                    resstr4a = ['shotgunCDFlogx' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr4a = ['mv -f shotgunCDFlogx.pdf ' resstr4a '; mv -f ' resstr4a ' ' resdir];
                                    [status,result] =  system(commandstr4a);
                                    resstr4b = ['shotgunCDFlogy' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr4b = ['mv -f shotgunCDFlogy.pdf ' resstr4b '; mv -f ' resstr4b ' ' resdir];
                                    [status,result] =  system(commandstr4b);
                                    resstr4c = ['shotgunCDFloglog' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr4c = ['mv -f shotgunCDFloglog.pdf ' resstr4c '; mv -f ' resstr4c ' ' resdir];
                                    [status,result] =  system(commandstr4c);
                                    
                                    resstr41 = ['shotgunCCDF' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr41 = ['mv -f shotgunCCDF.pdf ' resstr41 '; mv -f ' resstr41 ' ' resdir];
                                    [status,result] =  system(commandstr41);
                                    
                                    resstr41a = ['shotgunCCDFlogx' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr41a = ['mv -f shotgunCCDFlogx.pdf ' resstr41a '; mv -f ' resstr41a ' ' resdir];
                                    [status,result] =  system(commandstr41a);
                                    resstr41b = ['shotgunCCDFlogy' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr41b = ['mv -f shotgunCCDFlogy.pdf ' resstr41b '; mv -f ' resstr41b ' ' resdir];
                                    [status,result] =  system(commandstr41b);
                                    resstr41c = ['shotgunCCDFloglog' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr41c = ['mv -f shotgunCCDFloglog.pdf ' resstr41c '; mv -f ' resstr41c ' ' resdir];
                                    [status,result] =  system(commandstr41c);
                                    
                                    resstr5 = ['shotgunRELerror' int2str(traceid) '_nvars1_' int2str(nvars1) '_nvars2_' int2str(nvars2) '_cdfpoints' int2str(cdfpoints) '_K' int2str(K) '_pcdfonly' int2str(pdfcdffit_only)  '_penalty' int2str(stp_factor) '_gfit' int2str(gfitrunno) '.pdf'];
                                    commandstr5 = ['mv -f shotgunRELerror.pdf ' resstr5 '; mv -f ' resstr5 ' ' resdir];
                                    [status,result] =  system(commandstr5);
                                end
                            end
                        end
                    end
                end
            end
        end
    end
    fprintf(' Total number of experiments will be/was  %d.\n *********************************************************** \n STARTING/TERMINATING EXPERIMENT SERIES... \n\n',number_of_experiments);
end

res = 1;
