% File <lsqlin_own_version.m>
%
% Author: Falko Bause
% Date: June 2016
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%

% Function maybe useful in case Matlab's lsqlin function has problems....


function [x,resnorm,residual,exitflag,output,lambda,norm2_error] = lsqlin_own_version(C,d,A,b,Aeq,beq,lb,ub,x0,options,vers)

% just calls the lsqlin version of MATLAB or
% calls an equivalent version of quadprog
% dependent on flag vers

% if flag vers == 3 then several calls of lsqnonneg are used where the
% equality constraint is encoded into the objective function. vers == 3 is
% only possible if A=b=[] i.e. there are no inequality constraints.
% Furthermore the bound vectors lb,ub have to be empty

%fprintf('Start lsqlin call\n');
%printtime();

% [C,d] =  delete_zero_rows(C,d, 1.0e-6);



if (size(C,1) < size(C,2))
    fprintf('WARNING: underdetermined system for lsqlin_own_version call!!\n');
    fprintf('#Eqs: %d   #Vars: %d\n',size(C,1),size(C,2));
else
    fprintf('Adequate system for lsqlin_own_version call!!\n');
    fprintf('#Eqs: %d   #Vars: %d\n',size(C,1),size(C,2));
end
%cinput('Continue...(press key)');

if ( (size(Aeq,1) ~= 0) && (size(beq,1) ~= 0) && (size(x0,1) ~= 0) )
  fprintf('lsqlin_own_version step1: Conditions and Quality of start value are %E  %E\n',norm(Aeq*x0-beq,1),norm(C*x0-d,1));
%     if (norm(Aeq*x0-beq,1) > 1.0e-10)
%         % initial value violates equality constraints
%         x0 = linsolve(Aeq,beq);
%     end
    if (norm(Aeq*x0-beq,1) > 1.0e-4)
%         % initial value still violates equality constraints
%         fprintf('lsqlin_own_version: no appropriate value for start value found.\n');
        x0 = [];
    end
%   if (size(x0,1) ~= 0)
%       fprintf('lsqlin_own_version step2: Quality of start value is now %E \n',norm(Aeq*x0-beq,1));
%   end
end

if (vers == 1)
   [x,resnorm,residual,exitflag,output,lambda]  = lsqlin(C,d,A,b,Aeq,beq,lb,ub,x0,options);
   %if (exitflag ~= 1)
    fprintf('lsqlin_own_version  #Eqs: %d   #Vars: %d   exitflag: %d\n',size(C,1),size(C,2),exitflag);
   %end
end
if (vers == 2)
   residual = 0;
   H = C'*C;
   f = -C'*d;
   [x,fval,exitflag,output,lambda] = quadprog(H,f,A,b,Aeq,beq,lb,ub,x0,options);
   resnorm = fval;
end
if (vers == 3)
   assert((size(A,1) == 0 && size(b,1) == 0),'lsqlin_own_version: Inequality constraints are non-empty for lsqnonneg calls!');
   assert((size(lb,1) == 0 && size(ub,1) == 0),'lsqlin_own_version: Bounds are non-empty for lsqnonneg calls!');
   [x,resnorm,residual,exitflag,output,lambda] = lsqnonneg_iter(C,d,Aeq,beq,options);
end

 if ( (size(Aeq,1) ~= 0) && (size(beq,1) ~= 0) && (size(x0,1) ~= 0) )
  fprintf('lsqlin_own_version: Quality of start value was %E  Quality of result is 1-norm(C*x-d): %E  exitflag = %d\n',norm(C*x0-d,1),norm(C*x-d,1),exitflag);
  fprintf('lsqlin_own_version: Conditions and Quality of result are: %E  %E  exitflag = %d\n',norm(Aeq*x-beq,1),norm(C*x-d,1),exitflag); 
  norm2_error = norm(C*x-d,2);
  fprintf('\n\n lsqlin_own_version: Quality (norm-2!) of start value was %E  Quality (norm-2!) of result is 2-norm(C*x-d): %E  exitflag = %d\n',norm(C*x0-d,2),norm(C*x-d,2),exitflag);
 else
  norm2_error = norm(C*x-d,2);
  fprintf('lsqlin_own_version: Conditions and Quality of result are: %E  %E  exitflag = %d\n',norm(Aeq*x-beq,1),norm(C*x-d,1),exitflag);
end
fprintf('lsqlin_own_version: Minimum of result is %E \n',min(x));
output = output

 if ( (size(x0,1) ~= 0) &&  (size(x,1) ~= 0) )
   if ( norm(C*x0-d,2) < norm(C*x-d,2) )
     fprintf('lsqlin_own_version: Quality of start value is BETTER than quality of result! BAD PERFORMANCE OF lsqlin\n');
   end
end

