% File <lsqnonneg_iter.m>
%
% Author: Falko Bause
% Date: June 2016
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%

% Function might be useful if lsqlin has problems....


function [bestx,besterror,bestresidual,bestexitflag,bestoutput,bestlambda] = lsqnonneg_iter(C,d,Aeq,beq,options)

% encodes the equality constraints into the the objective function using
% different weighting factors and returns the solution with the minimum
% Aeq*x-beq error.

initialphase = 0;  % to ensure that this function gives at least some result.
bestconstrainterror =  1.0e+90;
besterror =  1.0e+90;
threshold = 1.0e-06;
maxwtmp = max(max(abs(vertcat(C,Aeq))));
wf = 0.01;
% Adjust the weighting factor until the violation of the constraints,
% which are now encoded in the objective function, is small.
while ( (wf <= 10^5) )
    weightfactor = wf * maxwtmp;
    Cnew = vertcat(C,(weightfactor*Aeq));
    dnew = vertcat(d,(weightfactor*beq));
    [x,~,residual,exitflag,output,lambda] = lsqnonneg(Cnew,dnew,options);

xtmp = x;
    x(x<0) = 0; % eliminate negative components which is necessary if lsqnonneg gives erroneously a negative solution
if (max(abs(xtmp-x))) > 10^(-6)
   fprintf('');
end
    
    fiterror = (norm(C*x-d))^2;           
    wf = 10*wf;
    constrainterror = max(max(abs(Aeq*x-beq)));
    fprintf('Function lsqnonneg_iter:  current constraint error = %E current fitting error = %E\n', constrainterror,fiterror);
    if ((constrainterror < threshold) || (initialphase <= 1))
        if (fiterror < besterror)
            if (initialphase <= 1)
               initialphase = 2;
               threshold = constrainterror;
            end
            bestx = x;
            besterror = fiterror;
            bestresidual = residual;
            bestexitflag = exitflag;
            bestoutput = output;
            bestlambda = lambda;
            bestconstrainterror = constrainterror;
            fprintf('Function lsqnonneg_iter: new best solution!  constraint error = %E     fitting error = %E\n',bestconstrainterror,besterror);
            bestx
            fprintf('\n\n');
        end
    end
end
