% File <plot_of_results.m>
%
% Author: Falko Bause
% Date: June 2016
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%
  

  function [ ] = plot_of_result(tracepdf, fittedpdf, tracecdf, fittedcdf, tracemoments, fittedmoments, pdftvalues, pdfmax_index, cdftvalues, cdfmax_index,jvm)
% Generate PDF files for comparison of original vs. fitted PDF and CDF/CCDF
% at grid values tvalues.
% Also generate a plot giving the relative errors of trace moments vs. moments
% of the fitted mixture distribution.

% Note that fixed file names (with prefix shotgun...) are used!

if (jvm <= 0)
    return;    % Matlab has been called with option -nojvm, so we can't use the figure functions for output, thus we do not generate any output figures.
end

    
if pdfmax_index > length(pdftvalues)
  pdfmax_index = length(pdftvalues);
  fprintf('plot_of_result: pdfmax_index is set to length(pdftvalues)!\n');
end
if cdfmax_index > length(cdftvalues)
  cdfmax_index = length(cdftvalues);
  fprintf('plot_of_result: cdfmax_index is set to length(cdftvalues)!\n');
end

figure(); set(gcf,'Visible', 'off');
plot(pdftvalues(1:pdfmax_index),tracepdf(1:pdfmax_index));
title('PDF');
legend('PDF Trace');
print('shotgunTRACEPDF','-dpdf');

figure(); set(gcf,'Visible', 'off');
plot(pdftvalues(1:pdfmax_index),tracepdf(1:pdfmax_index),pdftvalues(1:pdfmax_index),fittedpdf(1:pdfmax_index));
title('PDF');
legend('PDF Trace','PDF Fitted Distribution');
print('shotgunPDF','-dpdf');

figure(); set(gcf,'Visible', 'off');
semilogx(pdftvalues(1:pdfmax_index),tracepdf(1:pdfmax_index),pdftvalues(1:pdfmax_index),fittedpdf(1:pdfmax_index));
title('PDF log scale x-axis');
legend('PDF Trace','PDF Fitted Distribution','Location','northeast');
print('shotgunPDFlogx','-dpdf');
figure(); set(gcf,'Visible', 'off');
semilogy(pdftvalues(1:pdfmax_index),tracepdf(1:pdfmax_index),pdftvalues(1:pdfmax_index),fittedpdf(1:pdfmax_index));
title('PDF log scale y-axis');
legend('PDF Trace','PDF Fitted Distribution','Location','northeast');
print('shotgunPDFlogy','-dpdf');
figure(); set(gcf,'Visible', 'off');
loglog(pdftvalues(1:pdfmax_index),tracepdf(1:pdfmax_index),pdftvalues(1:pdfmax_index),fittedpdf(1:pdfmax_index));
title('PDF log-log scale');
legend('PDF Trace','PDF Fitted Distribution','Location','northeast');
print('shotgunPDFloglog','-dpdf');


figure(); set(gcf,'Visible', 'off');
plot(cdftvalues(1:cdfmax_index),tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),fittedcdf(1:cdfmax_index));
title('CDF');
legend('CDF Trace','CDF Fitted Distribution','Location','southeast');
print('shotgunCDF','-dpdf');

figure(); set(gcf,'Visible', 'off');
semilogx(cdftvalues(1:cdfmax_index),tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),fittedcdf(1:cdfmax_index));
title('CDF log scale x-axis');
legend('CDF Trace','CDF Fitted Distribution','Location','southeast');
print('shotgunCDFlogx','-dpdf');
figure(); set(gcf,'Visible', 'off');
semilogy(cdftvalues(1:cdfmax_index),tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),fittedcdf(1:cdfmax_index));
title('CDF log scale y-axis');
legend('CDF Trace','CDF Fitted Distribution','Location','southeast');
print('shotgunCDFlogy','-dpdf');
figure(); set(gcf,'Visible', 'off');
loglog(cdftvalues(1:cdfmax_index),tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),fittedcdf(1:cdfmax_index));
title('CDF log-log scale');
legend('CDF Trace','CDF Fitted Distribution','Location','southeast');
print('shotgunCDFloglog','-dpdf');


figure(); set(gcf,'Visible', 'off');
plot(cdftvalues(1:cdfmax_index),1.0-tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),1.0-fittedcdf(1:cdfmax_index));
title('CCDF');
legend('CCDF Trace','CCDF Fitted Distribution','Location','northeast');
print('shotgunCCDF','-dpdf');

figure(); set(gcf,'Visible', 'off');
semilogx(cdftvalues(1:cdfmax_index),1.0-tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),1.0-fittedcdf(1:cdfmax_index));
title('CCDF log scale x-axis');
legend('CCDF Trace','CCDF Fitted Distribution','Location','northeast');
print('shotgunCCDFlogx','-dpdf');
figure(); set(gcf,'Visible', 'off');
semilogy(cdftvalues(1:cdfmax_index),1.0-tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),1.0-fittedcdf(1:cdfmax_index));
title('CCDF log scale y-axis');
legend('CCDF Trace','CCDF Fitted Distribution','Location','northeast');
print('shotgunCCDFlogy','-dpdf');
figure(); set(gcf,'Visible', 'off');
loglog(cdftvalues(1:cdfmax_index),1.0-tracecdf(1:cdfmax_index),cdftvalues(1:cdfmax_index),1.0-fittedcdf(1:cdfmax_index));
title('CCDF log-log scale');
legend('CCDF Trace','CCDF Fitted Distribution','Location','northeast');
print('shotgunCCDFloglog','-dpdf');

figure(); set(gcf,'Visible', 'off');
Kdist = length(tracemoments);
relerror = abs((fittedmoments(2:Kdist)-tracemoments(2:Kdist))./tracemoments(2:Kdist));
K = length(relerror);
plot((1:K),relerror);
title('                       Relative Error of Moments of Fitted Distribution');
xlabel('Moment');
print('shotgunRELerror','-dpdf');
