% File <prettyprint.m>
%
% Author: Falko Bause
% Date: June 2016   changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%
% The result comprising a mixture of (determinisitc and) Erlang distributions
% is printed in LaTeX code

function prettyprint( tracefile,fittingtime,N,pivec,Ak,relerrormoments,norm2_error )

[~,fname,~] = fileparts(tracefile);
fprintf('\\documentclass[10pt]{article}\n\\begin{document} \n');
fprintf('\\begin{tabular}{|l|l|l|} \\hline \n');
fprintf('FILE: %s & Fitting time (sec.): %f & Norm-2 error of NNLS problem: %E \\\\ \\hline \n',strrep(fname, '_', '\_'),fittingtime,norm2_error);
fprintf('\\multicolumn{3}{|p{\\textwidth}|}{Fitted mixture of Erl./dtm. distributions ($(\\pi_i,\\lambda_i,n_i)$);  \\#Components = %d :} \\\\  \n',N);
str = '';
for i=1:N
        if (Ak{i}(1,2) == 123456789)
            if (size(str,1) == 0)
                str = strcat(str,'\mbox{(', num2str(pivec(i),'%1.3e'),',',num2str(Ak{i}(1,1),'%1.3e'),',','dt.)}');  % dt. for deterministic
            else
                str = strcat(str,', \mbox{(', num2str(pivec(i),'%1.3e'),',',num2str(Ak{i}(1,1),'%1.3e'),',','dt.)}');
            end
            continue
        end
    if (size(str,1) == 0)
      str = strcat(str,'\mbox{(', num2str(pivec(i),'%1.3e'),',',num2str(Ak{i}(1,1),'%1.3e'),',',num2str(Ak{i}(1,2),'%d'),')}');
    else
      str = strcat(str,', \mbox{(', num2str(pivec(i),'%1.3e'),',',num2str(Ak{i}(1,1),'%1.3e'),',',num2str(Ak{i}(1,2),'%d'),')}');
    end
end
fprintf('\\multicolumn{3}{|p{\\textwidth}|}{%s }  \\\\ \\hline \n',str);
fprintf('\\multicolumn{3}{|p{\\textwidth}|}{Relative errors of moments (starting with $0$-th moment):}  \\\\ \n');
relmomerror = repmat('%1.3e, ',1,length(relerrormoments));
relmomerror(end-1)=[]; %Remove last comma
fprintf(strcat('\\multicolumn{3}{|p{\\textwidth}|}{',relmomerror,'}  \\\\ \\hline \n'),relerrormoments);
fprintf('\\end{tabular} \n');
fprintf('\\end{document} \n');
end

