% File <printtrace_characteristics.m>
%
% Author: Falko Bause
% Date: June 2019   
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%
% This function prints essential characteristics of a trace like e.g. mean,
% median etc.
% quantile_number gives the number of quantiles for which the quantile
% values should be printed.

function printtrace_characteristics( tracefile, trace, tracename, quantile_number )
fprintf('\n*************************************************************\n');
fprintf('Characteristics of Trace %s (quantile_number = %d)\n\n', tracename,quantile_number);
fprintf('trace length              %E\n',length(trace));
fprintf('mean                      %E\n',mean(trace));
fprintf('median                    %E\n',median(trace));
fprintf('min                       %E\n',min(trace));
fprintf('max                       %E\n',max(trace));
fprintf('variance                  %E\n',var(trace));
fprintf('kurtosis                  %E\n',kurtosis(trace));
fprintf('skewness                  %E\n\n',skewness(trace));
qv = quantile(trace,quantile_number);
qvlen = length(qv);
fprintf('quantiles                             %E\n',qv);
fprintf('diff:= (max(trace) - max(quantiles):  %E\n',max(trace)-max(qv));
fprintf('diff / max(quantiles)  =              %E\n',((max(trace)-max(qv))/max(qv)));
fprintf('diff / median(trace)   =              %E\n',((max(trace)-max(qv))/median(trace)));
fprintf('\n');

% % Next lines probably only work on Linux systems (with tcsh/csh), so if running Matlab on other systems/shells comment them out
% if isunix
%      fprintf('Listing most common trace values   (Format:  number of occurrences  -- value):\n');
%      % if using bash shell   setenv needs to be replaced   (LC_ALL = C) ensures that sorting of numerical values in scientific notation works properly
%      commandstr = ['rm -f shotgun.origdistsort; setenv LC_ALL C; sort -g -k1 ' tracefile ' | uniq -c | sort -r -g -k1 > shotgun.origdistsort; head -10 shotgun.origdistsort'];
%      [status,result] =  system(commandstr);
%      fprintf('%s',result);
%      commandstr = ['rm -f shotgun.origdistsort'];
%      [~,~] =  system(commandstr);
% end

fprintf('\n\n');
end

