% File <unique_values.m>
%
% Author: Falko Bause
% Date: April 2018
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2016.
%


function [ values ] = unique_values(values,epsilon)

% sorts the numbers in values and eliminates all values that are less than epsilon apart, i.e.
% if values = [... v_i v_i+1 v_i+2 ...v_i+j v_i+j+1 ...] is the initial argument for the function call
% we return values = [... v_i v_i+j+1 ...] if |v_i - v_i+j| < espilon for all j and |v_i - v_i+j+1| > epsilon.

i=1;
nodeleted = 0;
values = sort(values); 
origlen = length(values);

while (i<length(values))
    
    for j=1:(length(values)-i)
        if (abs(values(i)-values(i+j)) < epsilon)
            values(i+j) = 0;
            nodeleted = nodeleted + 1;
        else
            i=i+1;
            values(values==0) = [];
            break;
        end
    end
end
values(values==0) = [];
fprintf('function unique_values:  original length of values vector: %d, number of deleted elements: %d\n',origlen,nodeleted);

