% File <writeprofido_hypererlang.m>
%
% Author: Falko Bause
% Date: December 2017  changed February 2018 (storage efficient representation of Ak)
%
% This file is part of the MATLAB functions for fitting mixture distributions
% Copyright (C) Falko Bause, Department of Computer Science, TU Dortmund, 2017.
%


function  writeprofido_hypererlang(pivec,Ak)
% writes matrices to file shotgun.profido
% in the interchange format of the tool ProFiDo
% see ls4-www.cs.tu-dortmund.de/profido


nophases = size(pivec,2);

last_element = pivec(nophases);
pivec = pivec/sum(pivec); % since the plot command of ProFiDo for parameter -dist  assumes an exact(!) stochastic vector
pivec(nophases) = 1.0 - sum(pivec(1:(nophases-1)));  

assumeandprint(abs(last_element-pivec(nophases)) < 1.0E-5,'Function writeprofido_hypererlang: Components of pivec do not sum up to one!! Significant difference!\n');

% fprintf('Sum of pivec:  %1.200f \n',sum(pivec));

fid = fopen('shotgun.profido','w');

fprintf(fid,'<?xml version="1.0"?>\n');
fprintf(fid,'<profido>\n');
fprintf(fid,'<dist>\n');
fprintf(fid,'<hypererlangdist>\n');
fprintf(fid,'<prob> ');
for i=1:nophases
  fprintf(fid,' %1.20f ',pivec(i)); 
end
fprintf(fid,'</prob>\n');

fprintf(fid,'<phases> ');
for i=1:nophases
        fprintf(fid,' %d ',Ak{i}(1,2));
end
fprintf(fid,'</phases>\n');


fprintf(fid,'<rates> ');
for i=1:nophases
        fprintf(fid,' %E ',Ak{i}(1,1));
end
fprintf(fid,'</rates>\n');

fprintf(fid,'</hypererlangdist>\n');
fprintf(fid,'</dist>\n');
fprintf(fid,'</profido>\n');

fclose(fid);
